//
//  CAPPDiskImage.h
//  DiskImage
//
//  Created by Tobias Kalus on 07.04.11.
//  Copyright 2011 Synium Software GmbH. All rights reserved.
//



enum
{
	CAPPDiskImageNoError = 1,
	CAPPDiskImageCreateError = -1,
	CAPPDiskImageCopyFilesError = -2,
	CAPPDiskImageMountError = -3,
	CAPPDiskImageUnmountError = -4,
	CAPPDiskImageCompressError = -5,
	CAPPDiskImageExtractError = -6,
	CAPPDiskImageDeleteError = -7
}
typedef CAPPDiskImageError;


@class CAPPDiskImage;


@protocol CAPPDiskImageDelegate

- (void)diskImageDidCreateSparseImage:(CAPPDiskImage *)diskImage;
- (void)diskImageDidMountSparseImage:(CAPPDiskImage *)diskImage;
- (void)diskImageDidCopyFilesToSparseImage:(CAPPDiskImage *)diskImage;
- (void)diskImageDidUnmountSparseImage:(CAPPDiskImage *)diskImage;
- (void)diskImageDidMount:(CAPPDiskImage *)diskImage;
- (void)diskImageDidCompress:(CAPPDiskImage *)diskImage;
- (void)diskImageDidUnmount:(CAPPDiskImage *)diskImage;
- (void)diskImageDidExtractFiles:(CAPPDiskImage *)diskImage;

@end


@interface CAPPDiskImage : NSObject 
{
	NSURL *url;
	NSString *title;
	
	BOOL sparseImage;
	BOOL sparseImageCreated;
	
	NSMutableDictionary *archiveInformationDictionary;
	unsigned long version;
	NSDate *date;
	NSMutableArray *fileList;
	
	NSMutableDictionary *aliasMap;
	
	id <CAPPDiskImageDelegate> delegate;
	
	NSDictionary *customArchiveInformation;
}

@property (assign) id <CAPPDiskImageDelegate> delegate;
@property (readonly) NSString *title;

- (id)initWithURL:(NSURL *)diskImageURL;

- (NSURL *)mountPointURL;

- (BOOL)mounted;

- (CAPPDiskImageError)compress;

- (CAPPDiskImageError)createWithContentURLs:(NSArray *)contentURLs customArchiveInformation:(NSDictionary *)infoDict;
- (CAPPDiskImageError)createWithContentURLs:(NSArray *)contentURLs;
- (CAPPDiskImageError)extractContentURLs:(NSArray *)contentURLs;

- (CAPPDiskImageError)convert:(NSURL *)outputDirectory;

- (CAPPDiskImageError)mount;
- (CAPPDiskImageError)unmount;
- (CAPPDiskImageError)moveToTrash;

- (NSDate *)date;
- (NSArray *)fileList;
- (NSDictionary *)customArchiveInformation;
- (long)version;

@end
