//
//  CAPPFileManager.h
//  CleanAppCore
//
//  Created by Tobias Kalus on 17.09.10.
//  Copyright 2010 Synium Software GmbH. All rights reserved.
//

#import "CAPPFileManagerTransaction.h"
#import "CAPPFileManagerResultCode.h"


@class CAPPProtectedPath;
@class CAPPFileManagerTransaction;


@interface CAPPFileManager : NSObject 
{
	AuthorizationItem *authorizationItems;
	AuthorizationRights authorizationRights;
	AuthorizationRef authorization;
	
	char *cleanAppCoreHelperPath;
	
	NSMutableArray *transactions;
	
	NSMutableDictionary *architectureMap;
}

+ (CAPPFileManager *)sharedInstance;

- (CAPPFileManagerTransaction *)beginTransactionWithAuthorizationOptions:(CAPPFileManagerTransactionAuthorizationOptions)authOptions;
- (void)endTransaction;

- (CAPPFileManagerResultCode)runCleanAppCoreHelperWithArguments:(char **)arguments output:(NSData **)output;
- (CAPPFileManagerResultCode)runCleanAppCoreHelperWithArguments:(char **)arguments;

- (CAPPFileManagerResultCode)executeFileAtURLWithAuthorization:(NSURL *)url arguments:(NSArray *)arguments waitUntilFinished:(BOOL)wait output:(NSString **)output;

- (CAPPFileManagerResultCode)executeShellScriptAtURLWithAuthorization:(NSURL *)url arguments:(NSArray *)arguments output:(NSString **)output;
- (CAPPFileManagerResultCode)executeDiskutilWithArguments:(NSArray *)arguments output:(NSString **)output;
- (CAPPFileManagerResultCode)changeOwnerOfFileAtURL:(NSURL *)url arguments:(NSArray *)arguments;
- (CAPPFileManagerResultCode)changePermissionsOfFileAtURL:(NSURL *)url arguments:(NSArray *)arguments;

- (CAPPFileManagerResultCode)executeBashCommandWithRootPrivileges:(NSString *)command;

- (NSImage *)iconForFileAtURL:(NSURL *)url;
- (NSImage *)iconForFilesAtURLs:(NSArray *)urls iconSize:(NSSize)iconSize;
- (NSDate *)modificationDateOfFileAtURL:(NSURL *)url;
- (NSDate *)creationDateOfFileAtURL:(NSURL *)url;
- (NSDate *)accessDateOfFileAtURL:(NSURL *)url;
- (unsigned long long)sizeOfFileAtURL:(NSURL *)url;
- (unsigned long long)sizeOfDirectoryAtURL:(NSURL *)url cancellationHandler:(BOOL *)cancel;
- (unsigned long long)sizeOfDirectoryAtURL:(NSURL *)url;
- (NSMutableArray *)contentsOfDirectoryAtURL:(NSURL *)url recursive:(BOOL)recursive cancellationHandler:(BOOL *)cancel;
- (NSMutableArray *)contentsOfDirectoryAtURL:(NSURL *)url recursive:(BOOL)recursive;
- (BOOL)isBundleAtURL:(NSURL *)url;
- (BOOL)isDirectoryAtURL:(NSURL *)url;
- (BOOL)isHiddenFileAtURL:(NSURL *)url;
- (BOOL)isAliasAtURL:(NSURL *)url;
- (BOOL)isSymlinkAtURL:(NSURL *)url;
- (BOOL)fileExistsAtURL:(NSURL *)url;
- (NSURL *)targetOfLinkAtURL:(NSURL *)url;
- (BOOL)isLockedFileAtURL:(NSURL *)url;
- (CAPPFileManagerResultCode)createDirectoryAtURL:(NSURL *)url;
- (CAPPFileManagerResultCode)createDirectoryAtURLWithIntermediateDirectories:(NSURL *)url;
- (CAPPFileManagerResultCode)deleteItemAtURL:(NSURL *)url;
- (CAPPFileManagerResultCode)moveFileAtURLToTrash:(NSURL *)url;
- (CAPPFileManagerResultCode)copyFileAtURL:(NSURL *)url toURL:(NSURL *)destinationURL;
- (CAPPFileManagerResultCode)moveFileAtURL:(NSURL *)url toURL:(NSURL *)destinationURL;
- (CAPPFileManagerResultCode)createAliasAtURL:(NSURL *)aliasURL targetURL:(NSURL *)targetURL;
- (CAPPFileManagerResultCode)createSymlinkAtURL:(NSURL *)symlinkURL targetURL:(NSURL *)targetURL isRelativePath:(BOOL)isRelativePath;
- (CAPPFileManagerResultCode)touchFileAtURL:(NSURL *)url;

- (BOOL)isApplicationAtURL:(NSURL *)url;
- (BOOL)isApplicationAtURL:(NSURL *)url iOSApplication:(BOOL *)iOSApplication;
- (BOOL)isMultiArchitectureBinaryAtURL:(NSURL *)url;
- (NSSet *)architecturesOfApplicationAtURL:(NSURL *)url;
- (BOOL)isDeletableArchitecture:(NSString *)architecture architectures:(NSSet *)architectures;
- (NSSet *)deletableArchitecturesOfApplicationAtURL:(NSURL *)url;
- (BOOL)removeArchitecture:(NSString *)architecture ofApplicatonAtURL:(NSURL *)url;
- (CAPPFileManagerResultCode)removeArchitectures:(NSArray *)architectures ofApplicatonAtURL:(NSURL *)url;
- (NSString *)CPUTypeForSubtype:(NSString *)subtype;
- (NSArray *)CPUSubtypesForType:(NSString *)type;

- (CAPPFileManagerResultCode)loadDaemonWithPropertyListURL:(NSURL *)url;
- (CAPPFileManagerResultCode)unloadDaemonWithPropertyListURL:(NSURL *)url;

- (CAPPFileManagerResultCode)unloadKernelExtensionWithURL:(NSURL *)url;

@end
