//
//  CAPPPathSearchController.h
//  CleanAppCore
//
//  Created by Tobias Kalus on 16.01.14.
//  Copyright (c) 2014 Synium Software GmbH. All rights reserved.
//

#import "CAPPIconCache.h"
#import "CAPPLanguageAuxiliaries.h"
#import "NSURL+Additions.h"
#import "CAPPPathProtectionRevisor.h"
#import "CAPPDirectoryExclusionManager.h"
#import "CAPPBasePathSearchController.h"


@class CAPPPathSearchController;


@protocol CAPPPathSearchControllerDelegate <NSObject>

- (void)pathSearchController:(CAPPPathSearchController *)controller didAddResult:(id)result;
- (void)pathSearchController:(CAPPPathSearchController *)controller didRemoveResult:(id)result;

@optional
- (void)pathSearchController:(CAPPPathSearchController *)controller didUpdateResult:(id)result;
- (void)pathSearchControllerWillStart:(CAPPPathSearchController *)controller;
- (void)pathSearchControllerDidStop:(CAPPPathSearchController *)controller;

@end


#define CAPPPathSearchControllerIsRunningKey @"isRunning"



@interface CAPPPathSearchController : CAPPBasePathSearchController
{
	NSHashTable *delegates;
	
	BOOL isRunning;
	BOOL didRun;
	BOOL wasStopped;
	
	NSMutableSet *results;
	NSMutableSet *preparedResults;
	NSMapTable *resultMap;
}
	
@property (readonly) NSSet *results;
@property (readonly) NSNumber *isRunning;
@property (readonly) NSNumber *didRun;

- (void)startSearch;
- (void)stopSearch;
- (void)stopSearch:(BOOL)waitUntilDone;

- (void)invalidate;

- (void)addDelegate:(id <CAPPPathSearchControllerDelegate>)delegate;
- (void)removeDelegate:(id <CAPPPathSearchControllerDelegate>)delegate;

- (void)notePathsWereDeleted:(NSSet *)paths;

@end
